@@ -1,7 +1,7 @@
 import json
-from urllib import urlopen
+from urllib.request import urlopen
 
-import pip
+import subprocess
 from pymongo import MongoClient
 
 
@@ -24,10 +24,4 @@ def start_config(code):
         db.config.insert(config)
 
         for pack in config['packages']:
-            pip.main(['install', pack["name"], '-U'])
-
-
-
-
-
-
+            subprocess.check_call(['pip3', 'install', pack["name"], '--force-reinstall'])
