@@ -11,6 +11,6 @@ def create_executor(robot_name, category):
     packages = config_db["packages"]
     package = filter(lambda x: x["category"] == category, packages)[0]
 
-    module = importlib.import_module(package["import"])
-    class_ = getattr(module, "executor")
+    module = importlib.import_module(package["name"] + ".executor")
+    class_ = getattr(module, package["class"])
     return class_()
