@@ -3,7 +3,6 @@ def boot():
     from robot_core.config import robot_config
     robot_config.start_config("boulder_mobile")
 
-
 def executor():
     from robot_core.executor import executor_factory
     eye = executor_factory.create_executor("Boulder Mobile", "eye")
@@ -12,5 +11,5 @@ def executor():
 
 
 if __name__ == '__main__':
-    # boot()
-    executor()
+    boot()
+    # executor()
